Owl Job Scheduler
=================

|Build Status| |Doc Status| |Version Status|

Owl is a job scheduler that allows to submit user jobs to a Kubernetes cluster from anywhere.
See documentation_ for more information.

Discussion
----------

Any feedback, ideas, enhancements, contributions are welcome. Head to the discussion_
to add yours or submit issues or bugs in the tracker_.

LICENSE
-------

GPL. See `License File <https://github.com/eddienko/owl-pipeline-server/blob/main/LICENSE>`__.

.. _documentation: https://eddienko.github.io/owl-pipeline/
.. _discussion: https://github.com/eddienko/owl-pipeline-server/discussions
.. _tracker: https://github.com/eddienko/owl-pipeline-server/issues
.. |Build Status| image:: https://github.com/eddienko/owl-pipeline-server/actions/workflows/CI.yml/badge.svg
   :target: https://github.com/eddienko/owl-pipeline-server/actions/workflows/CI.yml?query=workflow%3ACI
.. |Doc Status| image:: https://github.com/eddienko/owl-pipeline/actions/workflows/deploy-github.yml/badge.svg
   :target: https://eddienko.github.io/owl-pipeline/
.. |Version Status| image:: https://img.shields.io/pypi/v/owl-pipeline-server.svg
   :target: https://pypi.python.org/pypi/owl-pipeline-server


